<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Es gibt ein Leben außerhalb des Browsers!</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="26"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 ist freie Software, aber die Entwicklung kostet wertvolle Zeit.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="27"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Bitte &lt;a href=&apos;%1&apos;&gt;spende&lt;/a&gt;, um die ständige Entwicklung von %2 zu unterstützen.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="31"/>
        <source>You may want to try my other apps as well:</source>
        <translation>Vielleicht möchten Sie auch meine anderen Apps ausprobieren:</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="34"/>
        <source>%1, a YouTube music player</source>
        <translation>%1, ein YouTube-Musik-Player</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="38"/>
        <source>%1, a music player</source>
        <translation>%1, ein Musik-Player</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="44"/>
        <source>Translate %1 to your native language using %2</source>
        <translation>Übersetzen Sie %1 in Ihre Muttersprache mit %2</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="49"/>
        <source>Icon designed by %1.</source>
        <translation>Symbol-Entwurf durch %1.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="53"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Veröffentlicht unter der &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="65"/>
        <source>&amp;Close</source>
        <translation>S&amp;chließen</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="25"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="27"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Was Du schon immer über %1 wissen wolltest, aber nie zu fragen wagtest</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Säubern</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <location filename="local/src/demostartupview.cpp" line="35"/>
        <source>Please license %1</source>
        <translation>Bitte lizenzieren Sie %1</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="39"/>
        <source>This demo has expired.</source>
        <translation>Diese Demo ist abgelaufen.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="41"/>
        <source>The full version allows you to download videos longer than %1 minutes and to watch videos without interruptions.</source>
        <translation>Die Vollversion erlaubt es Ihnen Videos länger als %1 Minuten herunterzuladen und Videos ohne Unterbrechungen zu sehen.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="43"/>
        <source>This demo will expire in %1 days.</source>
        <translation>Diese Demo wird in %1 Tagen ablaufen.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="45"/>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Mit dem Kauf der Vollversion unterstützen Sie auch die harte Arbeit, die ich in die Erstellung von %1 gesteckt habe.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="57"/>
        <source>Use Demo</source>
        <translation>Demo verwenden</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="65"/>
        <source>Get the full version</source>
        <translation>Holen Sie sich die Vollversion</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="src/downloaditem.cpp" line="308"/>
        <source>bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="311"/>
        <source>KB</source>
        <translation>kB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="314"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="330"/>
        <source>bytes/sec</source>
        <translation>Bytes/s</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="333"/>
        <source>KB/sec</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="336"/>
        <source>MB/sec</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="342"/>
        <source>seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="345"/>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="348"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 verbleibend</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation>Dies ist nur die Demoversion von %1.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Sie kann nur Videos, die kürzer als %1 Minuten sind, herunterladen, damit die Download-Funktionalität getestet werden kann.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="55"/>
        <source>Continue</source>
        <translation>Fortfahren</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="56"/>
        <source>Get the full version</source>
        <translation>Die Vollversion holen</translation>
    </message>
    <message numerus="yes">
        <location filename="src/downloadmanager.cpp" line="137"/>
        <source>%n Download(s)</source>
        <translation><numerusform>%n Download</numerusform><numerusform>%n Downloads</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation>Speicherort ändern…</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation>Wähle den Speicherort</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation>Speicherort wurde verändert.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Aktuelle Downloads werden immernoch im alten Speicherort gespeichert.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation>Lade herunter nach: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="src/downloadview.cpp" line="18"/>
        <location filename="src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation>Abspielen/Pause</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation>Halt</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation>Nachdem aktueller Titel abgespielt wurde halten</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation>Nächster Titel</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation>Vorheriger Titel</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation>Lautstärke erhöhen</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation>Lautstärke verringern</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation>Stummschalten</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation>Vorwärts spulen</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation>Rückwärts spulen</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="src/ListModel.cpp" line="51"/>
        <source>Searching...</source>
        <translation>Suche...</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="52"/>
        <source>Show %1 More</source>
        <translation>Weitere %1 zeigen</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="53"/>
        <source>No videos</source>
        <translation>Keine Videos</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="54"/>
        <source>No more videos</source>
        <translation>Keine weiteren Videos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="160"/>
        <source>&amp;Stop</source>
        <translation>&amp;Halt</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="161"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Wiedergabe anhalten und zur Suchansicht zurückkehren</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="179"/>
        <source>S&amp;kip</source>
        <translation>Ü&amp;berspringen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="180"/>
        <source>Skip to the next video</source>
        <translation>Zum nächsten Video springen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="186"/>
        <location filename="src/MainWindow.cpp" line="835"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="187"/>
        <location filename="src/MainWindow.cpp" line="836"/>
        <source>Pause playback</source>
        <translation>Wiedergabe pausieren</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="193"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Vollbildmodus</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="194"/>
        <source>Go full screen</source>
        <translation>Vollbildmodus aktivieren</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="210"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Verstecke Abspielliste und Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="223"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gehe zur YouTube-Video-Seite und pausiere die Wiedergabe</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="230"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>YouTube-Link in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="237"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Video-URL in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="244"/>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Findet andere Teile des Videos, hoffentlich in der richtigen Reihenfolge</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="250"/>
        <source>&amp;Remove</source>
        <translation>Entfe&amp;rnen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="251"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Entferne das ausgewählte Video aus der Abspielliste</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="257"/>
        <source>Move &amp;Up</source>
        <translation>Bewege &amp;hinauf</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="258"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Bewege das ausgewählte Video in der Abspielliste hinauf</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="264"/>
        <source>Move &amp;Down</source>
        <translation>Bewege hin&amp;ab</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="265"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Bewege das ausgewählte Video in der Abspielliste hinunter</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="276"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Such-Verlauf leeren. Kann nicht rückgängig gemacht werden.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="281"/>
        <source>&amp;Quit</source>
        <translation>&amp;Verlassen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="284"/>
        <source>Bye</source>
        <translation>Tschüss</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="288"/>
        <source>&amp;Website</source>
        <translation>&amp;Webseite</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="290"/>
        <source>%1 on the Web</source>
        <translation>%1 im Web</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="296"/>
        <source>Please support the continued development of %1</source>
        <translation>Bitte unterstützen Sie die weitere Entwicklung von %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="301"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="303"/>
        <source>Info about %1</source>
        <translation>Informationen über %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="311"/>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="330"/>
        <source>Mute volume</source>
        <translation>Stummschalten</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="359"/>
        <location filename="src/MainWindow.cpp" line="1179"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Downloads</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="360"/>
        <source>Show details about video downloads</source>
        <translation>Details über Video-Downloads anzeigen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="368"/>
        <source>&amp;Download</source>
        <translation>H&amp;erunterladen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="369"/>
        <source>Download the current video</source>
        <translation>Das aktuelle Video herunterladen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="381"/>
        <source>Share the current video using %1</source>
        <translation>Teilen Sie das aktuellen Video mit %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="393"/>
        <source>&amp;Email</source>
        <translation>&amp;E-Mail</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="394"/>
        <source>Email</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="398"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="403"/>
        <source>&amp;Float on Top</source>
        <translation>Im Vordergrund &amp;bleiben</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="408"/>
        <source>&amp;Stop After This Video</source>
        <translation>Nach diesem Video &amp;anhalten</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="445"/>
        <source>&amp;Application</source>
        <translation>&amp;Anwendung</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="447"/>
        <source>Buy %1...</source>
        <translation>%1 kaufen...</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="458"/>
        <source>&amp;Playback</source>
        <translation>&amp;Wiedergabe</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="472"/>
        <source>&amp;Playlist</source>
        <translation>A&amp;bspielliste</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="479"/>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="490"/>
        <source>&amp;View</source>
        <translation>&amp;Ansehen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="497"/>
        <source>&amp;Share</source>
        <translation>&amp;Teilen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="509"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="586"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1 drücken, um die Lautstärke zu erhöhen, %2 um sie zu verringern</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="748"/>
        <location filename="src/MainWindow.cpp" line="754"/>
        <source>Opening %1</source>
        <translation>%1 öffnen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="787"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Möchten Sie %1 mit einem aktiven Download beenden?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="788"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Wenn Sie %1 jetzt beenden, wird der Download abgebrochen.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="793"/>
        <source>Close and cancel download</source>
        <translation>Beenden und Download abbrechen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="794"/>
        <source>Wait for download to finish</source>
        <translation>Auf Abschluß des Downloads warten</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="940"/>
        <source>Leave &amp;Full Screen</source>
        <translation>&amp;Vollbild verlassen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1283"/>
        <source>%1 version %2 is now available.</source>
        <translation>%1 Version %2 ist jetzt verfügbar.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1297"/>
        <source>Remind me later</source>
        <translation>Erinnere mich später</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1294"/>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation>Für die aktualisierte Version, laden Sie bitte %1 ,mit Hilfe des Links den Sie erhalten per E-Mail erhalten haben, runter und installieren Sie es erneut.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1301"/>
        <source>Update</source>
        <translation>Aktualisierung</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="828"/>
        <source>Error: %1</source>
        <translation>Fehler: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="169"/>
        <source>P&amp;revious</source>
        <translation>V&amp;origes</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="170"/>
        <source>Go back to the previous track</source>
        <translation>Zum vorherigen Titel zurückgehen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="209"/>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompakt-Modus</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="222"/>
        <source>Open the &amp;YouTube Page</source>
        <translation>&amp;YouTube-Seite öffnen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="229"/>
        <source>Copy the YouTube &amp;Link</source>
        <translation>YouTube &amp;Link kopieren</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="236"/>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Video-Stream &amp;URL kopieren</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="243"/>
        <source>Find Video &amp;Parts</source>
        <translation>Suche Video &amp;Teile</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="271"/>
        <source>&amp;Clear Recent Searches</source>
        <translation>Vorherige Suchbegriffe löschen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="295"/>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Spenden</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="352"/>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Manuelles Starten der Wiedergabe</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="353"/>
        <source>Manually start playing videos</source>
        <translation>Manuelles Starten der Video-Wiedergabe</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="848"/>
        <source>&amp;Play</source>
        <translation>&amp;Abspielen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="849"/>
        <source>Resume playback</source>
        <translation>Wiedergabe fortsetzen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1055"/>
        <source>Remaining time: %1</source>
        <translation>Verbleibende Zeit: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1113"/>
        <source>Volume at %1%</source>
        <translation>Lautstärke %1%</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1119"/>
        <source>Volume is muted</source>
        <translation>Ton ist stummgeschaltet</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1122"/>
        <source>Volume is unmuted</source>
        <translation>Ton ist angeschaltet</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1129"/>
        <source>Maximum video definition set to %1</source>
        <translation>Maximale Video-Auflösung wurde auf %1 gesetzt</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1165"/>
        <source>Your privacy is now safe</source>
        <translation>Ihre Privatsphäre ist nun geschützt</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1180"/>
        <source>Downloads complete</source>
        <translation>Downloads heruntergeladen</translation>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="58"/>
        <source>&amp;Window</source>
        <translation>&amp;Fenster</translation>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="61"/>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimieren</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="src/MediaView.cpp" line="35"/>
        <source>Most relevant</source>
        <translation>Die Bedeutsamsten</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="42"/>
        <source>Most recent</source>
        <translation>Die Neusten</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="49"/>
        <source>Most viewed</source>
        <translation>Meist gesehen</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="521"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Du kannst den YouTube-Link nun in einer anderen Anwendung einfügen</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="529"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Du kannst die Video-URL nun in einer anderen Anwendung einfügen</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="530"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>Der Link wird nur eine beschränkte Zeit gültig sein.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="629"/>
        <source>This is just the demo version of %1.</source>
        <translation>Dies ist nur eine Demoversion von %1.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="630"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Sie erlaubt Ihnen die Anwendung zu testen und zu schauen ob sie bei Ihnen läuft.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="660"/>
        <source>Continue</source>
        <translation>Fortfahren</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="749"/>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>von </translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="761"/>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>Teil</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="763"/>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>Episode</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="821"/>
        <source>Sent from %1</source>
        <translation>Gesendet von %1</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="637"/>
        <source>Get the full version</source>
        <translation>Die Vollversion holen</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="682"/>
        <source>Downloading %1</source>
        <translation>%1 herunterladen</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="src/networkaccess.cpp" line="214"/>
        <source>Network error: %1</source>
        <translation>Netzwerk-Fehler: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="170"/>
        <source>%1 views</source>
        <translation>%1 mal betrachtet</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 von %2 (%3) – %4</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation>Bereite vor</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation>Fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation>Fertiggestellt</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation>Gestoppt</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation>Herunterladen stoppen</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation>In %1 anzeigen</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation>Eltern-Ordner öffnen</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation>Herunterladen neustarten</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="src/SearchView.cpp" line="79"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Willkommen bei &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="46"/>
        <source>Get the full version</source>
        <translation>Die Vollversion holen</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="93"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Eingeben</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="98"/>
        <source>a keyword</source>
        <translation>ein Schlüsselwort</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="99"/>
        <source>a channel</source>
        <translation>ein Kanal</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="104"/>
        <source>to start watching videos.</source>
        <translation>um die Wiedergabe zu starten.</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="128"/>
        <source>Watch</source>
        <translation>Anschauen</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="146"/>
        <source>Recent keywords</source>
        <translation>Aktuelle Schlüsselwörter</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation>Aktuelle Kanäle</translation>
    </message>
    <message>
        <location filename="src/SearchView.h" line="26"/>
        <source>Make yourself comfortable</source>
        <translation>Machen Sie es sich gemütlich</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="src/video.cpp" line="200"/>
        <source>Cannot get video stream for %1</source>
        <translation>Videostream für %1 konnte nicht öffnen werden</translation>
    </message>
    <message>
        <location filename="src/video.cpp" line="218"/>
        <source>Network error: %1 for %2</source>
        <translation>Netzwerk-Fehler: %1 für %2</translation>
    </message>
</context>
</TS>